Versionshistorie
================

Hier sind die wichtigsten Änderungen in den einzelnen Versionen von Evar aufgeführt.

Version 0.1.0
-------------

* Die Geschichten von <https://www.einfachvorlesen.de/> werden im akutellen Verzeichnis als PDF und Epub gespeichert.
